<?php

namespace Drupal\access_by_ref\Controller;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Provides a listing of Example.
 */
class AbrconfigListBuilder extends ConfigEntityListBuilder {
  /**
   * {@inheritdoc}
   */
  public function buildHeader() {

    $header['id'] = $this->t('Machine name');
    $header['label'] = $this->t('Label');
    $header['bundle'] = $this->t('Bundle');
    $header['reference_type'] = $this->t('Reference type');
    $header['extra'] = $this->t('Extra');
    $header['rights_type'] = $this->t('Rights type');
    //$header['rights_read'] = $this->t('Read?');
    //$header['rights_update'] = $this->t('Update?');
    //$header['rights_delete'] = $this->t('Delete?');

    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['id'] = $entity->id();
    $row['label'] = $entity->label();
    $row['bundle'] = $entity->getBundle();
    $row['reference_type'] = $entity->getReferencetype(true);
    $row['extra'] = $entity->getExtra();
    $row['rights_type'] = $entity->getRightsType();
    // $row['rights_read']  = ($entity->getRightsRead() == true) ? 'X' : '';
    // $row['rights_update']  = ($entity->getRightsUpdate() == true) ? 'X' : '';
    // $row['rights_delete']  = ($entity->getRightsDelete() == true) ? 'X' : '';

    // You probably want a few more properties here...

    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function render() {

    $info = "<p>This module extends update permissions to modules not owned by the current user. It works in several modes. The current user may update if:
            <ul>
            <li><b>User Referenced:</b> If a user is referenced in the relevant user reference field</li>
            <li><b>User Mail:</b> If the user's email matches (case insensitive) the email entered in the referenced email field</li>
            <li><b>Profile value:</b> IIf the value in the user's profile matches the value in the controlling field</li>
            <li><b>Inherit from parent:</b> <i>Best Choice</i> The user has edit rights over a node referenced in the controlling field</li>";
    // <li><b>Link FROM Parent:</b> <i>Risky</i> The node is referenced from a node the user can edit. If the user can edit that field, it gives them extensive control over site content</li>
    // <li><b>Secret Code:</b> <i>Experimental</i> The URL includes a parameter that matches the value of the field. E.g. ?field_foo=bar</li>
    $info .= "</ul></p>";
    $info .= "<p>These accesses will only be available to a user with the Access By Reference permissions, so be sure to set those</p>";
    $info .= "<p><b>To Use:</b> Select the content type to be controlled, and then the type of access you want to grant. Choose the field that will contain the effective data or link. In case we are looking for matched values, such as the 'Profile Value', specify in the Extra Field the field in the User Profile that has to match</p>";

    $form['info'] = array(
      '#type' => 'item',
      '#markup' => $info
    );

    $build['description'] = [
      '#prefix' => '<div>',
      '#markup' => $this->t($info, [
        ':components' => Url::fromRoute('entity.abrconfig.collection')->toString(),
        ':documentation' => 'https://www.drupal.org/node/',
      ]),
      '#suffix' => '</div>',
    ];

    $build['table'] = [
      '#type' => 'table',
      '#header' => $this->buildHeader(),
      '#title' => $this->getTitle(),
      '#rows' => [],
      '#empty' => $this->t('There are no @label yet.', ['@label' => $this->entityType->getPluralLabel()]),
      '#cache' => [
        'contexts' => $this->entityType->getListCacheContexts(),
        'tags' => $this->entityType->getListCacheTags(),
      ],
    ];
    foreach ($this->load() as $entity) {
      if ($row = $this->buildRow($entity)) {
        $build['table']['#rows'][$entity->id()] = $row;
      }
    }

    // Only add the pager if a limit is specified.
    if ($this->limit) {
      $build['pager'] = [
        '#type' => 'pager',
      ];
    }
    return $build;
  }

}